pub struct MockEndpoint(/* private fields */);Expand description
A mock endpoint that records all exchanges sent to it.
This is a thin wrapper around Arc<MockEndpointInner>. Multiple
MockEndpoint instances created with the same name share the same inner
storage.